#ifndef DEFINES_H
#define DEFINES_H

#define VERSION "LibreMediaServerAudio 0.2.0 Antigona Release"
#define COPYRIGHT "(C) 2014-2024 Santi Noreña <lms@criptomart.net>"
#define LICENSE "GPL 3 Licensed. See LICENSE.txt."
#define DEFAULT_FILE "lms-audio.xlm"
#define MAX_LAYERS 4
#define MAX_AUDIODEVICES 8
#define UI_REFRESH_TIME 100
#define FADE_TIME 25 // DMX Frame time, 40 fps, avoid clicks
#define FILTER_CHANNELS 13 // number of dmx channels dedicated to filters by layer

struct dmxSetting {
    int address;
    unsigned int universe;
    int layer;
    int audioDevice;
};

enum class Status
{
    Stopped,
    Paused,
    PlayingOnce,
    PlayingLoop,
    Iddle,
    PlayingFolder,
    PlayingFolderLoop,
    PlayingFolderRandom
};

constexpr const char* statusToString(Status e) noexcept
{
    switch (e)
    {
        case Status::Stopped: return "Stop";
        case Status::Paused: return "Paused";
        case Status::PlayingOnce: return "Play 1";
        case Status::PlayingLoop: return "Play Loop";
        case Status::Iddle: return "Iddle";
        case Status::PlayingFolder: return "Play Folder";
        case Status::PlayingFolderLoop: return "Play Folder Loop";
        case Status::PlayingFolderRandom: return "Playing Folder Random";
        default: return "--++--";
    }
}
/*
static const char* StatusStr[] =
{
    "Stop",
    "Pause",
    "Play One",
    "Play One Loop",
    "Iddle",
    "Play Folder",
    "Play Folder Loop",
    "Play Folder Rand",
    0x0
};*/

enum Slider
{
    Volume,
    Pan,
    Pitch,
};

#include <QString>
struct layerData {
    QString media;
    Status status;
    bool updated;
    float vol;
    float cursor;
    int pan;
    int pitch;
    float duration;
    int address;
    unsigned int universe;
    int device;
};
#endif // DEFINES_H
